==> Iuno-3.2.6.11211.tar.gz: Iuno-3.2.6.11211/Iuno/Email.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 11186 2018-08-05 05:18:00Z Lavender $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-08-05 14:18:00 +0900 (週日, 05 八月 2018) $
# $Revision: 11186 $

import traceback
import logging

from des.backends import ConfiguredEmailBackend as _ConfiguredEmailBackend
from des.models import DynamicEmailConfiguration
from django.conf import settings
from django.core.mail.backends.smtp import EmailBackend as SmtpEmailBackend

from Iuppiter.Logging import createLogger

logger = createLogger(__name__)

class ConfiguredEmailBackend(_ConfiguredEmailBackend):
    def send_messages(self, email_messages):
        fromEmailList = []
        try:
            fromEmail = DynamicEmailConfiguration.objects.get().from_email
            for message in email_messages:
                fromEmailList.append(message.from_email)
                if not message.from_email == settings.DEFAULT_FROM_EMAIL:
                    message.from_email = fromEmail

            return super(
                ConfiguredEmailBackend, self).send_messages(email_messages)
        except Exception as e:
            for i, message in enumerate(email_messages, 0):
                message.from_email = fromEmailList[i]
            errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
                    (str(e), traceback.format_exc()))
            logger.error(errMsg)
            smtp = SmtpEmailBackend()
            return smtp.send_messages(email_messages)

==> Iuno-3.7.7.11753.tar.gz: Iuno-3.7.7.11753/Iuno/Email.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 11186 2018-08-05 05:18:00Z Lavender $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-08-05 14:18:00 +0900 (週日, 05 八月 2018) $
# $Revision: 11186 $

import traceback
import logging

from des.backends import ConfiguredEmailBackend as _ConfiguredEmailBackend
from des.models import DynamicEmailConfiguration
from django.conf import settings
from django.core.mail.backends.smtp import EmailBackend as SmtpEmailBackend

from Iuppiter.Logging import createLogger

logger = createLogger(__name__)

class ConfiguredEmailBackend(_ConfiguredEmailBackend):
    def send_messages(self, email_messages):
        fromEmailList = []
        try:
            fromEmail = DynamicEmailConfiguration.objects.get().from_email
            for message in email_messages:
                fromEmailList.append(message.from_email)
                if not message.from_email == settings.DEFAULT_FROM_EMAIL:
                    message.from_email = fromEmail

            return super(
                ConfiguredEmailBackend, self).send_messages(email_messages)
        except Exception as e:
            for i, message in enumerate(email_messages, 0):
                message.from_email = fromEmailList[i]
            errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
                    (str(e), traceback.format_exc()))
            logger.error(errMsg)
            smtp = SmtpEmailBackend()
            try:
                r = smtp.send_messages(email_messages)
                return r
            except Exception as e:
                errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
                    (str(e), traceback.format_exc()))
                logger.error(errMsg)
                for message in email_messages:
                    if not message.from_email == settings.DEFAULT_FROM_EMAIL:
                        message.from_email = fromEmail
                
                try:                
                    r = smtp.send_messages(email_messages)
                    return r
                except Exception as e:
                    errMsg = ("ERROR: %s\n%s\nError send email" % 
                    (str(e), traceback.format_exc()))
                    logger.error(errMsg)
                    return
